This crate contains kube-rs compatible bindings for Kubernetes custom resources for the bus.volcano.sh group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
bus.volcano.sh/v1alpha1
Command